import abc
from typing import Any


class BaseContent(metaclass=abc.ABCMeta):
    """
    Базовый класс контента отчёта.

    Под контентом отчёта подразумевается объект использующийся для описания
    преобразования произвольных данных для заполнения отчёта в подготовленные
    данные для объекта отчёта.
    """
    @abc.abstractmethod
    def render(self, context: Any) -> Any:
        """
        Преобразование контекста отчёта в данные объекта отчёта.

        Под контекстом отчёта подразумеваются данные используемые для
        заполнения отчёта.

        :param context: Контекст отчёта
        :return: Данные объекта отчёта
        """
        raise NotImplementedError
