import abc
from typing import Any


class BaseWriter(metaclass=abc.ABCMeta):
    """
    Базовый класс-писатель для отчёта.

    Используется как точка взаимодействия библиотеки с библиотеками
    использующимися для записи отчёта.

    Как правило используется внутри простых объектов отчёта, но может быть
    использован отдельно.
    """
    @abc.abstractmethod
    def write(self, row: int, col: int, data: Any) -> None:
        """
        Запись данных в отчёт.

        :param row: Индекс строки для записи
        :param col: Индекс колонки для записи
        :param data: Данные для записи
        """
        raise NotImplementedError
