from typing import TYPE_CHECKING
from typing import Any
from typing import Type

from report_writer.impl.xlsx.report.writers.base import BaseReportWriter
from report_writer.impl.xlsx.report.writers.simple import CellWriter
from report_writer.impl.xlsx.utils.coordinates import get_cells_range
from report_writer.impl.xlsx.utils.coordinates import get_coordinates


if TYPE_CHECKING:
    from report_writer.impl.xlsx.report.report_file import ReportFile


class MergeWriter(BaseReportWriter):
    """
    Писатель для объединения клеток.

    :param report: Файл отчёта
    :param width: Ширина объединения
    :param height: Высота объединения
    """
    def __init__(self, report: 'ReportFile', height: int, width: int) -> None:
        super(MergeWriter, self).__init__(report)
        self._height: int = height
        self._width: int = width

    def write(self, row: int, col: int, data: Any) -> None:
        cells_range = get_cells_range(
            get_coordinates(row, col),
            get_coordinates(row + self._height - 1, col + self._width - 1))
        self._report.worksheet.merge_cells(cells_range)


class MergedCellWriter(MergeWriter):
    """
    Писатель объединённой клетки.
    """
    merge_writer_cls: 'Type[MergeWriter]' = MergeWriter

    def write(self, row: int, col: int, data: Any) -> None:
        super(MergedCellWriter, self).write(row, col, data)
        CellWriter(self._report).write(row, col, data)
